# Table of Contents

- [application-portfolio-management-onboarding-dashboard-for-enterprise-architects](<./application-portfolio-management-onboarding-dashboard-for-enterprise-architects.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Application Portfolio Management Onboarding Dashboard for Enterprise Architects](<./Application-Portfolio-Management-Onboarding-Dashboard-for-Enterprise-Architects.md>)
  - [Overview](<./Application-Portfolio-Management-Onboarding-Dashboard-for-Enterprise-Architects/Overview.md>)
  - [Dashboard Versions](<./Application-Portfolio-Management-Onboarding-Dashboard-for-Enterprise-Architects/Dashboard-Versions.md>)
  - [Activating the Dashboard](<./Application-Portfolio-Management-Onboarding-Dashboard-for-Enterprise-Architects/Activating-the-Dashboard.md>)
  - [Updating the Dashboard](<./Application-Portfolio-Management-Onboarding-Dashboard-for-Enterprise-Architects/Updating-the-Dashboard.md>)
  - [Understanding Best-Practice Metrics](<./Application-Portfolio-Management-Onboarding-Dashboard-for-Enterprise-Architects/Understanding-Best-Practice-Metrics.md>)
